#!/usr/bin/python
# coding = utf-8

from setuptools import setup

setup(
    name='my-state-machine',
    version='0.0.0',
    description='Simple State Machine',
    long_description='''You can use this library to build a state machine.
    ''',
    author='Wenhan Zhang',
    license='MIT License',
    platforms='any',
    packages=['my_state_machine']
)


from my_state_machine import StateMachine

a1 = StateMachine()

a1.i.D1 = 0
a1.o.Q1 = 0

@a1.inner()
def a1_step(i, o):
    o.Q1 = 1 - i.D1

a1.connect('Q1', a1, 'D1')

for i in range(10):
    a1.step()
    a1.send()
    print(a1)